# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.teams_api import TeamsApi


class TestTeamsApi(unittest.TestCase):
    """TeamsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TeamsApi()

    def tearDown(self) -> None:
        pass

    def test_create_team(self) -> None:
        """Test case for create_team

        Create team
        """
        pass

    def test_delete_team(self) -> None:
        """Test case for delete_team

        Delete team
        """
        pass

    def test_get_team(self) -> None:
        """Test case for get_team

        Get team by ID
        """
        pass

    def test_get_teams(self) -> None:
        """Test case for get_teams

        Get all teams
        """
        pass

    def test_update_team(self) -> None:
        """Test case for update_team

        Update team
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.get_dynamic_parameter_values import GetDynamicParameterValues

class TestGetDynamicParameterValues(unittest.TestCase):
    """GetDynamicParameterValues unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetDynamicParameterValues:
        """Test GetDynamicParameterValues
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetDynamicParameterValues`
        """
        model = GetDynamicParameterValues()
        if include_optional:
            return GetDynamicParameterValues(
                event_id = '',
                parameters = [
                    instana_client.models.dynamic_parameter.DynamicParameter(
                        key = '', 
                        name = '', 
                        resolved_value = '', 
                        tag_name = '', )
                    ],
                timestamp = 56
            )
        else:
            return GetDynamicParameterValues(
                event_id = '',
                parameters = [
                    instana_client.models.dynamic_parameter.DynamicParameter(
                        key = '', 
                        name = '', 
                        resolved_value = '', 
                        tag_name = '', )
                    ],
                timestamp = 56,
        )
        """

    def testGetDynamicParameterValues(self):
        """Test GetDynamicParameterValues"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr
from typing import List, Optional
from typing_extensions import Annotated
from instana_client.models.config_version import ConfigVersion
from instana_client.models.global_application_alert_config_with_metadata import GlobalApplicationAlertConfigWithMetadata
from instana_client.models.global_applications_alert_config import GlobalApplicationsAlertConfig

from instana_client.api_client import ApiClient, RequestSerialized
from instana_client.api_response import ApiResponse
from instana_client.rest import RESTResponseType


class GlobalApplicationAlertConfigurationApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def create_global_application_alert_config(
        self,
        global_applications_alert_config: GlobalApplicationsAlertConfig,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GlobalApplicationAlertConfigWithMetadata:
        """Create Global Smart Alert Config

        Creates a new Global Smart Alert Configuration. For more information on Global Alert Configuration please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Applications#global-application-alert-configuration.

        :param global_applications_alert_config: (required)
        :type global_applications_alert_config: GlobalApplicationsAlertConfig
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_global_application_alert_config_serialize(
            global_applications_alert_config=global_applications_alert_config,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GlobalApplicationAlertConfigWithMetadata",
            '400': None,
            '403': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def create_global_application_alert_config_with_http_info(
        self,
        global_applications_alert_config: GlobalApplicationsAlertConfig,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GlobalApplicationAlertConfigWithMetadata]:
        """Create Global Smart Alert Config

        Creates a new Global Smart Alert Configuration. For more information on Global Alert Configuration please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Applications#global-application-alert-configuration.

        :param global_applications_alert_config: (required)
        :type global_applications_alert_config: GlobalApplicationsAlertConfig
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_global_application_alert_config_serialize(
            global_applications_alert_config=global_applications_alert_config,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GlobalApplicationAlertConfigWithMetadata",
            '400': None,
            '403': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def create_global_application_alert_config_without_preload_content(
        self,
        global_applications_alert_config: GlobalApplicationsAlertConfig,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create Global Smart Alert Config

        Creates a new Global Smart Alert Configuration. For more information on Global Alert Configuration please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Applications#global-application-alert-configuration.

        :param global_applications_alert_config: (required)
        :type global_applications_alert_config: GlobalApplicationsAlertConfig
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_global_application_alert_config_serialize(
            global_applications_alert_config=global_applications_alert_config,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GlobalApplicationAlertConfigWithMetadata",
            '400': None,
            '403': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _create_global_application_alert_config_serialize(
        self,
        global_applications_alert_config,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if global_applications_alert_config is not None:
            _body_params = global_applications_alert_config


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/events/settings/global-alert-configs/applications',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def delete_global_application_alert_config(
        self,
        id: Annotated[StrictStr, Field(description="ID of a specific Global Smart Alert Configuration to delete.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Delete Global Smart Alert Config

        Disables a Global Smart Alert Configuration. For more information on Global Alert Configuration please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Applications#global-application-alert-configuration.

        :param id: ID of a specific Global Smart Alert Configuration to delete. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_global_application_alert_config_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def delete_global_application_alert_config_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="ID of a specific Global Smart Alert Configuration to delete.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Delete Global Smart Alert Config

        Disables a Global Smart Alert Configuration. For more information on Global Alert Configuration please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Applications#global-application-alert-configuration.

        :param id: ID of a specific Global Smart Alert Configuration to delete. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_global_application_alert_config_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def delete_global_application_alert_config_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="ID of a specific Global Smart Alert Configuration to delete.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete Global Smart Alert Config

        Disables a Global Smart Alert Configuration. For more information on Global Alert Configuration please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Applications#global-application-alert-configuration.

        :param id: ID of a specific Global Smart Alert Configuration to delete. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_global_application_alert_config_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _delete_global_application_alert_config_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/api/events/settings/global-alert-configs/applications/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def disable_global_application_alert_config(
        self,
        id: Annotated[StrictStr, Field(description="ID of a specific Global Smart Alert Configuration to disable.")],
        body: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Disable Global Smart Alert Config

        Disables a Global Smart Alert Configuration. For more information on Global Alert Configuration please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Applications#global-application-alert-configuration.

        :param id: ID of a specific Global Smart Alert Configuration to disable. (required)
        :type id: str
        :param body:
        :type body: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._disable_global_application_alert_config_serialize(
            id=id,
            body=body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def disable_global_application_alert_config_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="ID of a specific Global Smart Alert Configuration to disable.")],
        body: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Disable Global Smart Alert Config

        Disables a Global Smart Alert Configuration. For more information on Global Alert Configuration please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Applications#global-application-alert-configuration.

        :param id: ID of a specific Global Smart Alert Configuration to disable. (required)
        :type id: str
        :param body:
        :type body: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._disable_global_application_alert_config_serialize(
            id=id,
            body=body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def disable_global_application_alert_config_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="ID of a specific Global Smart Alert Configuration to disable.")],
        body: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Disable Global Smart Alert Config

        Disables a Global Smart Alert Configuration. For more information on Global Alert Configuration please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Applications#global-application-alert-configuration.

        :param id: ID of a specific Global Smart Alert Configuration to disable. (required)
        :type id: str
        :param body:
        :type body: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._disable_global_application_alert_config_serialize(
            id=id,
            body=body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _disable_global_application_alert_config_serialize(
        self,
        id,
        body,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if body is not None:
            _body_params = body



        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/api/events/settings/global-alert-configs/applications/{id}/disable',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def enable_global_application_alert_config(
        self,
        id: Annotated[StrictStr, Field(description="ID of a specific Global Smart Alert Configuration to enable.")],
        body: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Enable Global Smart Alert Config

        Enables a Global Smart Alert Configuration. For more information on Global Alert Configuration please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Applications#global-application-alert-configuration.

        :param id: ID of a specific Global Smart Alert Configuration to enable. (required)
        :type id: str
        :param body:
        :type body: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._enable_global_application_alert_config_serialize(
            id=id,
            body=body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def enable_global_application_alert_config_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="ID of a specific Global Smart Alert Configuration to enable.")],
        body: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Enable Global Smart Alert Config

        Enables a Global Smart Alert Configuration. For more information on Global Alert Configuration please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Applications#global-application-alert-configuration.

        :param id: ID of a specific Global Smart Alert Configuration to enable. (required)
        :type id: str
        :param body:
        :type body: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._enable_global_application_alert_config_serialize(
            id=id,
            body=body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def enable_global_application_alert_config_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="ID of a specific Global Smart Alert Configuration to enable.")],
        body: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Enable Global Smart Alert Config

        Enables a Global Smart Alert Configuration. For more information on Global Alert Configuration please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Applications#global-application-alert-configuration.

        :param id: ID of a specific Global Smart Alert Configuration to enable. (required)
        :type id: str
        :param body:
        :type body: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._enable_global_application_alert_config_serialize(
            id=id,
            body=body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _enable_global_application_alert_config_serialize(
        self,
        id,
        body,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if body is not None:
            _body_params = body



        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/api/events/settings/global-alert-configs/applications/{id}/enable',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def find_active_global_application_alert_configs(
        self,
        application_id: Annotated[StrictStr, Field(description="The ID of a specific global application.")],
        alert_ids: Annotated[Optional[Annotated[List[StrictStr], Field(min_length=0, max_length=1000)]], Field(description="A list of Global Smart Alert Configuration IDs. This allows fetching of a specific set of Configurations. This query can be repeated to use multiple IDs.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[GlobalApplicationAlertConfigWithMetadata]:
        """Get all Global Smart Alert Configs

        Gets all Global Smart Alert Configuration. Configurations are sorted by creation date in descending order. For more information on Global Alert Configuration please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Applications#global-application-alert-configuration.

        :param application_id: The ID of a specific global application. (required)
        :type application_id: str
        :param alert_ids: A list of Global Smart Alert Configuration IDs. This allows fetching of a specific set of Configurations. This query can be repeated to use multiple IDs.
        :type alert_ids: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._find_active_global_application_alert_configs_serialize(
            application_id=application_id,
            alert_ids=alert_ids,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[GlobalApplicationAlertConfigWithMetadata]",
            '403': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def find_active_global_application_alert_configs_with_http_info(
        self,
        application_id: Annotated[StrictStr, Field(description="The ID of a specific global application.")],
        alert_ids: Annotated[Optional[Annotated[List[StrictStr], Field(min_length=0, max_length=1000)]], Field(description="A list of Global Smart Alert Configuration IDs. This allows fetching of a specific set of Configurations. This query can be repeated to use multiple IDs.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[GlobalApplicationAlertConfigWithMetadata]]:
        """Get all Global Smart Alert Configs

        Gets all Global Smart Alert Configuration. Configurations are sorted by creation date in descending order. For more information on Global Alert Configuration please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Applications#global-application-alert-configuration.

        :param application_id: The ID of a specific global application. (required)
        :type application_id: str
        :param alert_ids: A list of Global Smart Alert Configuration IDs. This allows fetching of a specific set of Configurations. This query can be repeated to use multiple IDs.
        :type alert_ids: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._find_active_global_application_alert_configs_serialize(
            application_id=application_id,
            alert_ids=alert_ids,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[GlobalApplicationAlertConfigWithMetadata]",
            '403': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def find_active_global_application_alert_configs_without_preload_content(
        self,
        application_id: Annotated[StrictStr, Field(description="The ID of a specific global application.")],
        alert_ids: Annotated[Optional[Annotated[List[StrictStr], Field(min_length=0, max_length=1000)]], Field(description="A list of Global Smart Alert Configuration IDs. This allows fetching of a specific set of Configurations. This query can be repeated to use multiple IDs.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get all Global Smart Alert Configs

        Gets all Global Smart Alert Configuration. Configurations are sorted by creation date in descending order. For more information on Global Alert Configuration please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Applications#global-application-alert-configuration.

        :param application_id: The ID of a specific global application. (required)
        :type application_id: str
        :param alert_ids: A list of Global Smart Alert Configuration IDs. This allows fetching of a specific set of Configurations. This query can be repeated to use multiple IDs.
        :type alert_ids: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._find_active_global_application_alert_configs_serialize(
            application_id=application_id,
            alert_ids=alert_ids,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[GlobalApplicationAlertConfigWithMetadata]",
            '403': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _find_active_global_application_alert_configs_serialize(
        self,
        application_id,
        alert_ids,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'alertIds': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if application_id is not None:
            
            _query_params.append(('applicationId', application_id))
            
        if alert_ids is not None:
            
            _query_params.append(('alertIds', alert_ids))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/events/settings/global-alert-configs/applications',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def find_global_application_alert_config(
        self,
        id: Annotated[StrictStr, Field(description="ID of a specific Global Smart Alert Configuration to retrieve.")],
        valid_on: Annotated[Optional[StrictInt], Field(description="A Unix timestamp representing a specific time the Configuration was active. If no timestamp is provided, the latest active version will be retrieved. ")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GlobalApplicationAlertConfigWithMetadata:
        """Get Global Smart Alert Config

        Gets a specific Global Smart Alert Configuration. This may return a deleted Configuration. For more information on Global Alert Configuration please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Applications#global-application-alert-configuration.

        :param id: ID of a specific Global Smart Alert Configuration to retrieve. (required)
        :type id: str
        :param valid_on: A Unix timestamp representing a specific time the Configuration was active. If no timestamp is provided, the latest active version will be retrieved. 
        :type valid_on: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._find_global_application_alert_config_serialize(
            id=id,
            valid_on=valid_on,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GlobalApplicationAlertConfigWithMetadata",
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def find_global_application_alert_config_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="ID of a specific Global Smart Alert Configuration to retrieve.")],
        valid_on: Annotated[Optional[StrictInt], Field(description="A Unix timestamp representing a specific time the Configuration was active. If no timestamp is provided, the latest active version will be retrieved. ")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GlobalApplicationAlertConfigWithMetadata]:
        """Get Global Smart Alert Config

        Gets a specific Global Smart Alert Configuration. This may return a deleted Configuration. For more information on Global Alert Configuration please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Applications#global-application-alert-configuration.

        :param id: ID of a specific Global Smart Alert Configuration to retrieve. (required)
        :type id: str
        :param valid_on: A Unix timestamp representing a specific time the Configuration was active. If no timestamp is provided, the latest active version will be retrieved. 
        :type valid_on: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._find_global_application_alert_config_serialize(
            id=id,
            valid_on=valid_on,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GlobalApplicationAlertConfigWithMetadata",
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def find_global_application_alert_config_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="ID of a specific Global Smart Alert Configuration to retrieve.")],
        valid_on: Annotated[Optional[StrictInt], Field(description="A Unix timestamp representing a specific time the Configuration was active. If no timestamp is provided, the latest active version will be retrieved. ")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Global Smart Alert Config

        Gets a specific Global Smart Alert Configuration. This may return a deleted Configuration. For more information on Global Alert Configuration please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Applications#global-application-alert-configuration.

        :param id: ID of a specific Global Smart Alert Configuration to retrieve. (required)
        :type id: str
        :param valid_on: A Unix timestamp representing a specific time the Configuration was active. If no timestamp is provided, the latest active version will be retrieved. 
        :type valid_on: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._find_global_application_alert_config_serialize(
            id=id,
            valid_on=valid_on,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GlobalApplicationAlertConfigWithMetadata",
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _find_global_application_alert_config_serialize(
        self,
        id,
        valid_on,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        if valid_on is not None:
            
            _query_params.append(('validOn', valid_on))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/events/settings/global-alert-configs/applications/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def find_global_application_alert_config_versions(
        self,
        id: Annotated[StrictStr, Field(description="ID of a specific Global Smart Alert Configuration to retrieve.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[ConfigVersion]:
        """Get Global Smart Alert Config Versions

        Gets all versions of a Global Smart Alert Configuration. This may return deleted Configurations. Configurations are sorted by creation date in descending order. For more information on Global Alert Configuration please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Applications#global-application-alert-configuration.

        :param id: ID of a specific Global Smart Alert Configuration to retrieve. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._find_global_application_alert_config_versions_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[ConfigVersion]",
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def find_global_application_alert_config_versions_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="ID of a specific Global Smart Alert Configuration to retrieve.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[ConfigVersion]]:
        """Get Global Smart Alert Config Versions

        Gets all versions of a Global Smart Alert Configuration. This may return deleted Configurations. Configurations are sorted by creation date in descending order. For more information on Global Alert Configuration please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Applications#global-application-alert-configuration.

        :param id: ID of a specific Global Smart Alert Configuration to retrieve. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._find_global_application_alert_config_versions_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[ConfigVersion]",
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def find_global_application_alert_config_versions_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="ID of a specific Global Smart Alert Configuration to retrieve.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Global Smart Alert Config Versions

        Gets all versions of a Global Smart Alert Configuration. This may return deleted Configurations. Configurations are sorted by creation date in descending order. For more information on Global Alert Configuration please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Applications#global-application-alert-configuration.

        :param id: ID of a specific Global Smart Alert Configuration to retrieve. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._find_global_application_alert_config_versions_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[ConfigVersion]",
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _find_global_application_alert_config_versions_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/events/settings/global-alert-configs/applications/{id}/versions',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def restore_global_application_alert_config(
        self,
        id: Annotated[StrictStr, Field(description="ID of a specific Global Smart Alert Configuration to restore.")],
        created: Annotated[StrictInt, Field(description="Unix timestamp representing the creation time of a specific Global Smart Alert Configuration.")],
        body: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Restore Global Smart Alert Config

        Restores a deleted Global Smart Alert Configuration. For more information on Global Alert Configuration please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Applications#global-application-alert-configuration.

        :param id: ID of a specific Global Smart Alert Configuration to restore. (required)
        :type id: str
        :param created: Unix timestamp representing the creation time of a specific Global Smart Alert Configuration. (required)
        :type created: int
        :param body:
        :type body: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._restore_global_application_alert_config_serialize(
            id=id,
            created=created,
            body=body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def restore_global_application_alert_config_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="ID of a specific Global Smart Alert Configuration to restore.")],
        created: Annotated[StrictInt, Field(description="Unix timestamp representing the creation time of a specific Global Smart Alert Configuration.")],
        body: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Restore Global Smart Alert Config

        Restores a deleted Global Smart Alert Configuration. For more information on Global Alert Configuration please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Applications#global-application-alert-configuration.

        :param id: ID of a specific Global Smart Alert Configuration to restore. (required)
        :type id: str
        :param created: Unix timestamp representing the creation time of a specific Global Smart Alert Configuration. (required)
        :type created: int
        :param body:
        :type body: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._restore_global_application_alert_config_serialize(
            id=id,
            created=created,
            body=body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def restore_global_application_alert_config_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="ID of a specific Global Smart Alert Configuration to restore.")],
        created: Annotated[StrictInt, Field(description="Unix timestamp representing the creation time of a specific Global Smart Alert Configuration.")],
        body: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Restore Global Smart Alert Config

        Restores a deleted Global Smart Alert Configuration. For more information on Global Alert Configuration please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Applications#global-application-alert-configuration.

        :param id: ID of a specific Global Smart Alert Configuration to restore. (required)
        :type id: str
        :param created: Unix timestamp representing the creation time of a specific Global Smart Alert Configuration. (required)
        :type created: int
        :param body:
        :type body: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._restore_global_application_alert_config_serialize(
            id=id,
            created=created,
            body=body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _restore_global_application_alert_config_serialize(
        self,
        id,
        created,
        body,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        if created is not None:
            _path_params['created'] = created
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if body is not None:
            _body_params = body



        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/api/events/settings/global-alert-configs/applications/{id}/restore/{created}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def update_global_application_alert_config(
        self,
        id: Annotated[StrictStr, Field(description="ID of a specific Global Smart Alert Configuration to update.")],
        global_applications_alert_config: GlobalApplicationsAlertConfig,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GlobalApplicationAlertConfigWithMetadata:
        """Update Global Smart Alert Config

        Updates an existing Global Smart Alert Configuration. For more information on Global Alert Configuration please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Applications#global-application-alert-configuration.

        :param id: ID of a specific Global Smart Alert Configuration to update. (required)
        :type id: str
        :param global_applications_alert_config: (required)
        :type global_applications_alert_config: GlobalApplicationsAlertConfig
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_global_application_alert_config_serialize(
            id=id,
            global_applications_alert_config=global_applications_alert_config,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GlobalApplicationAlertConfigWithMetadata",
            '204': None,
            '400': None,
            '403': None,
            '422': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def update_global_application_alert_config_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="ID of a specific Global Smart Alert Configuration to update.")],
        global_applications_alert_config: GlobalApplicationsAlertConfig,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GlobalApplicationAlertConfigWithMetadata]:
        """Update Global Smart Alert Config

        Updates an existing Global Smart Alert Configuration. For more information on Global Alert Configuration please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Applications#global-application-alert-configuration.

        :param id: ID of a specific Global Smart Alert Configuration to update. (required)
        :type id: str
        :param global_applications_alert_config: (required)
        :type global_applications_alert_config: GlobalApplicationsAlertConfig
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_global_application_alert_config_serialize(
            id=id,
            global_applications_alert_config=global_applications_alert_config,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GlobalApplicationAlertConfigWithMetadata",
            '204': None,
            '400': None,
            '403': None,
            '422': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def update_global_application_alert_config_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="ID of a specific Global Smart Alert Configuration to update.")],
        global_applications_alert_config: GlobalApplicationsAlertConfig,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Update Global Smart Alert Config

        Updates an existing Global Smart Alert Configuration. For more information on Global Alert Configuration please access the https://developer.ibm.com/apis/catalog/instana--instana-rest-api/Applications#global-application-alert-configuration.

        :param id: ID of a specific Global Smart Alert Configuration to update. (required)
        :type id: str
        :param global_applications_alert_config: (required)
        :type global_applications_alert_config: GlobalApplicationsAlertConfig
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_global_application_alert_config_serialize(
            id=id,
            global_applications_alert_config=global_applications_alert_config,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GlobalApplicationAlertConfigWithMetadata",
            '204': None,
            '400': None,
            '403': None,
            '422': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _update_global_application_alert_config_serialize(
        self,
        id,
        global_applications_alert_config,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if global_applications_alert_config is not None:
            _body_params = global_applications_alert_config


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/events/settings/global-alert-configs/applications/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from instana_client.models.policy_scheduling import PolicyScheduling
from typing import Optional, Set
from typing_extensions import Self

class Trigger(BaseModel):
    """
    The trigger is the Instana event or Smart Alert that defines the initial conditions that must be met for the policy to apply on the actions in `typeConfiguration`.
    """ # noqa: E501
    description: Optional[StrictStr] = Field(default=None, description="A description for the trigger.")
    id: Optional[StrictStr] = Field(default=None, description="Trigger (Instana event or Smart Alert) identifier.")
    name: Optional[StrictStr] = Field(default=None, description="A name of the trigger (name of Instana event or Smart Alert).")
    scheduling: Optional[PolicyScheduling] = None
    type: StrictStr = Field(description="Instana event type, Smart Alert type, or 'schedule'. The type must be one of the enum values.")
    __properties: ClassVar[List[str]] = ["description", "id", "name", "scheduling", "type"]

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['customEvent', 'builtinEvent', 'applicationSmartAlert', 'globalApplicationSmartAlert', 'websiteSmartAlert', 'infraSmartAlert', 'mobileAppSmartAlert', 'syntheticsSmartAlert', 'logSmartAlert', 'sloSmartAlert', 'schedule']):
            raise ValueError("must be one of enum values ('customEvent', 'builtinEvent', 'applicationSmartAlert', 'globalApplicationSmartAlert', 'websiteSmartAlert', 'infraSmartAlert', 'mobileAppSmartAlert', 'syntheticsSmartAlert', 'logSmartAlert', 'sloSmartAlert', 'schedule')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Trigger from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of scheduling
        if self.scheduling:
            _dict['scheduling'] = self.scheduling.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Trigger from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "description": obj.get("description"),
            "id": obj.get("id"),
            "name": obj.get("name"),
            "scheduling": PolicyScheduling.from_dict(obj["scheduling"]) if obj.get("scheduling") is not None else None,
            "type": obj.get("type")
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.kubernetes_physical_context import KubernetesPhysicalContext

class TestKubernetesPhysicalContext(unittest.TestCase):
    """KubernetesPhysicalContext unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> KubernetesPhysicalContext:
        """Test KubernetesPhysicalContext
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `KubernetesPhysicalContext`
        """
        model = KubernetesPhysicalContext()
        if include_optional:
            return KubernetesPhysicalContext(
                cluster = instana_client.models.snapshot_preview.SnapshotPreview(
                    data = {
                        'key' : None
                        }, 
                    id = '', 
                    label = '', 
                    plugin = '', 
                    time = 1, ),
                namespace = instana_client.models.snapshot_preview.SnapshotPreview(
                    data = {
                        'key' : None
                        }, 
                    id = '', 
                    label = '', 
                    plugin = '', 
                    time = 1, ),
                node = instana_client.models.snapshot_preview.SnapshotPreview(
                    data = {
                        'key' : None
                        }, 
                    id = '', 
                    label = '', 
                    plugin = '', 
                    time = 1, ),
                pod = instana_client.models.snapshot_preview.SnapshotPreview(
                    data = {
                        'key' : None
                        }, 
                    id = '', 
                    label = '', 
                    plugin = '', 
                    time = 1, )
            )
        else:
            return KubernetesPhysicalContext(
        )
        """

    def testKubernetesPhysicalContext(self):
        """Test KubernetesPhysicalContext"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.run_configuration import RunConfiguration

class TestRunConfiguration(unittest.TestCase):
    """RunConfiguration unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RunConfiguration:
        """Test RunConfiguration
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RunConfiguration`
        """
        model = RunConfiguration()
        if include_optional:
            return RunConfiguration(
                actions = [
                    instana_client.models.action_configuration.ActionConfiguration(
                        action = instana_client.models.action.Action(
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            description = '', 
                            fields = [
                                instana_client.models.field.Field(
                                    description = '', 
                                    encoding = '', 
                                    name = '', 
                                    secured = True, 
                                    value = '', )
                                ], 
                            id = '0', 
                            input_parameters = [
                                instana_client.models.parameter.Parameter(
                                    description = '', 
                                    hidden = True, 
                                    label = '', 
                                    name = '', 
                                    required = True, 
                                    secured = True, 
                                    type = '', 
                                    value = '', )
                                ], 
                            metadata = instana_client.models.meta_data.MetaData(
                                ai = [
                                    {
                                        'key' : None
                                        }
                                    ], 
                                ai_originated = True, 
                                built_in = True, 
                                read_only = True, 
                                sensor_imported = True, ), 
                            modified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            name = '0', 
                            tags = [
                                ''
                                ], 
                            type = 'SCRIPT', ), 
                        agent_id = '', 
                        input_parameter_values = [
                            instana_client.models.parameter_value.ParameterValue(
                                name = '', 
                                value = '', )
                            ], )
                    ]
            )
        else:
            return RunConfiguration(
                actions = [
                    instana_client.models.action_configuration.ActionConfiguration(
                        action = instana_client.models.action.Action(
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            description = '', 
                            fields = [
                                instana_client.models.field.Field(
                                    description = '', 
                                    encoding = '', 
                                    name = '', 
                                    secured = True, 
                                    value = '', )
                                ], 
                            id = '0', 
                            input_parameters = [
                                instana_client.models.parameter.Parameter(
                                    description = '', 
                                    hidden = True, 
                                    label = '', 
                                    name = '', 
                                    required = True, 
                                    secured = True, 
                                    type = '', 
                                    value = '', )
                                ], 
                            metadata = instana_client.models.meta_data.MetaData(
                                ai = [
                                    {
                                        'key' : None
                                        }
                                    ], 
                                ai_originated = True, 
                                built_in = True, 
                                read_only = True, 
                                sensor_imported = True, ), 
                            modified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            name = '0', 
                            tags = [
                                ''
                                ], 
                            type = 'SCRIPT', ), 
                        agent_id = '', 
                        input_parameter_values = [
                            instana_client.models.parameter_value.ParameterValue(
                                name = '', 
                                value = '', )
                            ], )
                    ],
        )
        """

    def testRunConfiguration(self):
        """Test RunConfiguration"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.event_result import EventResult

class TestEventResult(unittest.TestCase):
    """EventResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> EventResult:
        """Test EventResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `EventResult`
        """
        model = EventResult()
        if include_optional:
            return EventResult(
                detail = '',
                end = 56,
                entity_label = '',
                entity_name = '',
                entity_type = '',
                event_id = '',
                event_specification_id = '',
                fix_suggestion = '',
                metrics = [
                    {
                        'key' : None
                        }
                    ],
                probable_cause = {
                    'key' : None
                    },
                problem = '',
                recent_events = [
                    {
                        'key' : None
                        }
                    ],
                severity = 56,
                snapshot_id = '',
                start = 56,
                state = '',
                type = ''
            )
        else:
            return EventResult(
        )
        """

    def testEventResult(self):
        """Test EventResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.api_team_scope import ApiTeamScope

class TestApiTeamScope(unittest.TestCase):
    """ApiTeamScope unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiTeamScope:
        """Test ApiTeamScope
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiTeamScope`
        """
        model = ApiTeamScope()
        if include_optional:
            return ApiTeamScope(
                access_permissions = [
                    'LIMITED_APPLICATIONS_SCOPE'
                    ],
                action_filter = '',
                applications = [
                    ''
                    ],
                business_perspectives = [
                    ''
                    ],
                infra_dfq_filter = '',
                kubernetes_clusters = [
                    ''
                    ],
                kubernetes_namespaces = [
                    ''
                    ],
                log_filter = '',
                mobile_apps = [
                    ''
                    ],
                restricted_application_filter = instana_client.models.api_restricted_application_filter.ApiRestrictedApplicationFilter(
                    label = '', 
                    restricting_application_id = '', 
                    scope = 'INCLUDE_NO_DOWNSTREAM', 
                    tag_filter_expression = instana_client.models.tag_filter_expression_element.TagFilterExpressionElement(
                        type = '', ), ),
                slo_ids = [
                    ''
                    ],
                synthetic_credentials = [
                    ''
                    ],
                synthetic_tests = [
                    ''
                    ],
                tag_ids = [
                    ''
                    ],
                websites = [
                    ''
                    ]
            )
        else:
            return ApiTeamScope(
        )
        """

    def testApiTeamScope(self):
        """Test ApiTeamScope"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from instana_client.models.service_levels_static_threshold_config import ServiceLevelsStaticThresholdConfig
from typing import Optional, Set
from typing_extensions import Self

class ServiceLevelsBurnRateConfig(BaseModel):
    """
    This is the burn rate alert configuration which defines alerting windows and corresponding thresholds. This configuration must to specified for BURN_RATE_V2 Alerts.
    """ # noqa: E501
    alert_window_type: Optional[StrictStr] = Field(default=None, description="Specifies the Burn Rate Alerting Window type: SINGLE for single window/threshold alerts, or LONG and SHORT for multi-window/threshold alerts.", alias="alertWindowType")
    duration: StrictInt = Field(description="Duration of the Burn Rate Alerting Window.")
    duration_unit_type: StrictStr = Field(description="Duration Unit Type of the Burn Rate Alerting Window.", alias="durationUnitType")
    threshold: ServiceLevelsStaticThresholdConfig
    __properties: ClassVar[List[str]] = ["alertWindowType", "duration", "durationUnitType", "threshold"]

    @field_validator('alert_window_type')
    def alert_window_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['SINGLE', 'LONG', 'SHORT']):
            raise ValueError("must be one of enum values ('SINGLE', 'LONG', 'SHORT')")
        return value

    @field_validator('duration_unit_type')
    def duration_unit_type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['millisecond', 'second', 'minute', 'hour', 'day', 'week', 'month']):
            raise ValueError("must be one of enum values ('millisecond', 'second', 'minute', 'hour', 'day', 'week', 'month')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServiceLevelsBurnRateConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of threshold
        if self.threshold:
            _dict['threshold'] = self.threshold.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServiceLevelsBurnRateConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "alertWindowType": obj.get("alertWindowType"),
            "duration": obj.get("duration"),
            "durationUnitType": obj.get("durationUnitType"),
            "threshold": ServiceLevelsStaticThresholdConfig.from_dict(obj["threshold"]) if obj.get("threshold") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.api_token import ApiToken

class TestApiToken(unittest.TestCase):
    """ApiToken unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiToken:
        """Test ApiToken
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiToken`
        """
        model = ApiToken()
        if include_optional:
            return ApiToken(
                access_granting_token = '',
                can_configure_agent_run_mode = True,
                can_configure_agents = True,
                can_configure_ai_agents = True,
                can_configure_apdex = True,
                can_configure_api_tokens = True,
                can_configure_application_smart_alerts = True,
                can_configure_applications = True,
                can_configure_authentication_methods = True,
                can_configure_automation_actions = True,
                can_configure_automation_policies = True,
                can_configure_bizops = True,
                can_configure_database_management = True,
                can_configure_eum_applications = True,
                can_configure_events_and_alerts = True,
                can_configure_global_alert_payload = True,
                can_configure_global_application_smart_alerts = True,
                can_configure_global_infra_smart_alerts = True,
                can_configure_global_log_smart_alerts = True,
                can_configure_global_synthetic_smart_alerts = True,
                can_configure_integrations = True,
                can_configure_llm = True,
                can_configure_log_management = True,
                can_configure_log_retention_period = True,
                can_configure_maintenance_windows = True,
                can_configure_mobile_app_monitoring = True,
                can_configure_mobile_app_smart_alerts = True,
                can_configure_personal_api_tokens = True,
                can_configure_releases = True,
                can_configure_service_level_correction_windows = True,
                can_configure_service_level_smart_alerts = True,
                can_configure_service_levels = True,
                can_configure_service_mapping = True,
                can_configure_session_settings = True,
                can_configure_subtraces = True,
                can_configure_synthetic_credentials = True,
                can_configure_synthetic_locations = True,
                can_configure_synthetic_tests = True,
                can_configure_teams = True,
                can_configure_users = True,
                can_configure_website_smart_alerts = True,
                can_create_heap_dump = True,
                can_create_public_custom_dashboards = True,
                can_create_thread_dump = True,
                can_delete_automation_action_history = True,
                can_delete_logs = True,
                can_edit_all_accessible_custom_dashboards = True,
                can_install_new_agents = True,
                can_invoke_alert_channel = True,
                can_manually_close_issue = True,
                can_run_automation_actions = True,
                can_use_synthetic_credentials = True,
                can_view_account_and_billing_information = True,
                can_view_audit_log = True,
                can_view_biz_alerts = True,
                can_view_business_activities = True,
                can_view_business_process_details = True,
                can_view_business_processes = True,
                can_view_log_volume = True,
                can_view_logs = True,
                can_view_synthetic_locations = True,
                can_view_synthetic_test_results = True,
                can_view_synthetic_tests = True,
                can_view_trace_details = True,
                created_by = '',
                created_on = 56,
                expires_on = 56,
                id = '',
                internal_id = '',
                last_used_on = 56,
                limited_ai_gateway_scope = True,
                limited_alert_channels_scope = True,
                limited_applications_scope = True,
                limited_automation_scope = True,
                limited_biz_ops_scope = True,
                limited_gen_ai_scope = True,
                limited_infrastructure_scope = True,
                limited_kubernetes_scope = True,
                limited_linux_kvm_hypervisor_scope = True,
                limited_logs_scope = True,
                limited_mobile_apps_scope = True,
                limited_nutanix_scope = True,
                limited_openstack_scope = True,
                limited_pcf_scope = True,
                limited_phmc_scope = True,
                limited_pvc_scope = True,
                limited_service_level_scope = True,
                limited_synthetics_scope = True,
                limited_vsphere_scope = True,
                limited_websites_scope = True,
                limited_windows_hypervisor_scope = True,
                limited_xen_server_scope = True,
                limited_zhmc_scope = True,
                name = ''
            )
        else:
            return ApiToken(
                access_granting_token = '',
                internal_id = '',
                name = '',
        )
        """

    def testApiToken(self):
        """Test ApiToken"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.validated_maintenance_config_v2_with_state_and_occurrence import ValidatedMaintenanceConfigV2WithStateAndOccurrence

class TestValidatedMaintenanceConfigV2WithStateAndOccurrence(unittest.TestCase):
    """ValidatedMaintenanceConfigV2WithStateAndOccurrence unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ValidatedMaintenanceConfigV2WithStateAndOccurrence:
        """Test ValidatedMaintenanceConfigV2WithStateAndOccurrence
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ValidatedMaintenanceConfigV2WithStateAndOccurrence`
        """
        model = ValidatedMaintenanceConfigV2WithStateAndOccurrence()
        if include_optional:
            return ValidatedMaintenanceConfigV2WithStateAndOccurrence(
                application_names = [
                    ''
                    ],
                id = '',
                invalid = True,
                last_updated = 1,
                name = '',
                occurrence = instana_client.models.occurrence.Occurrence(
                    end = 1, 
                    start = 0, ),
                paused = True,
                query = '',
                retrigger_open_alerts_enabled = True,
                scheduling = instana_client.models.maintenance_config_scheduling.MaintenanceConfigScheduling(
                    duration = instana_client.models.duration.Duration(
                        amount = 1, 
                        unit = 'MINUTES', ), 
                    start = 1, 
                    type = '', ),
                state = 'UNSCHEDULED',
                tag_filter_expression = instana_client.models.tag_filter_expression_element.TagFilterExpressionElement(
                    type = '', ),
                tag_filter_expression_enabled = True
            )
        else:
            return ValidatedMaintenanceConfigV2WithStateAndOccurrence(
                id = '',
                name = '',
                occurrence = instana_client.models.occurrence.Occurrence(
                    end = 1, 
                    start = 0, ),
                query = '',
                scheduling = instana_client.models.maintenance_config_scheduling.MaintenanceConfigScheduling(
                    duration = instana_client.models.duration.Duration(
                        amount = 1, 
                        unit = 'MINUTES', ), 
                    start = 1, 
                    type = '', ),
        )
        """

    def testValidatedMaintenanceConfigV2WithStateAndOccurrence(self):
        """Test ValidatedMaintenanceConfigV2WithStateAndOccurrence"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.synthetic_resource_update_list_dns_filter_target_value_list_dns_filter_target_value import SyntheticResourceUpdateListDNSFilterTargetValueListDNSFilterTargetValue

class TestSyntheticResourceUpdateListDNSFilterTargetValueListDNSFilterTargetValue(unittest.TestCase):
    """SyntheticResourceUpdateListDNSFilterTargetValueListDNSFilterTargetValue unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SyntheticResourceUpdateListDNSFilterTargetValueListDNSFilterTargetValue:
        """Test SyntheticResourceUpdateListDNSFilterTargetValueListDNSFilterTargetValue
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SyntheticResourceUpdateListDNSFilterTargetValueListDNSFilterTargetValue`
        """
        model = SyntheticResourceUpdateListDNSFilterTargetValueListDNSFilterTargetValue()
        if include_optional:
            return SyntheticResourceUpdateListDNSFilterTargetValueListDNSFilterTargetValue(
                add = [
                    instana_client.models.dns_filter_target_value.DNSFilterTargetValue(
                        key = 'ALL', 
                        operator = 'CONTAINS', 
                        value = '', )
                    ],
                remove = [
                    instana_client.models.dns_filter_target_value.DNSFilterTargetValue(
                        key = 'ALL', 
                        operator = 'CONTAINS', 
                        value = '', )
                    ]
            )
        else:
            return SyntheticResourceUpdateListDNSFilterTargetValueListDNSFilterTargetValue(
        )
        """

    def testSyntheticResourceUpdateListDNSFilterTargetValueListDNSFilterTargetValue(self):
        """Test SyntheticResourceUpdateListDNSFilterTargetValueListDNSFilterTargetValue"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class ApiToken(BaseModel):
    """
    ApiToken
    """ # noqa: E501
    access_granting_token: StrictStr = Field(alias="accessGrantingToken")
    can_configure_agent_run_mode: Optional[StrictBool] = Field(default=None, alias="canConfigureAgentRunMode")
    can_configure_agents: Optional[StrictBool] = Field(default=None, alias="canConfigureAgents")
    can_configure_ai_agents: Optional[StrictBool] = Field(default=None, alias="canConfigureAiAgents")
    can_configure_apdex: Optional[StrictBool] = Field(default=None, alias="canConfigureApdex")
    can_configure_api_tokens: Optional[StrictBool] = Field(default=None, alias="canConfigureApiTokens")
    can_configure_application_smart_alerts: Optional[StrictBool] = Field(default=None, alias="canConfigureApplicationSmartAlerts")
    can_configure_applications: Optional[StrictBool] = Field(default=None, alias="canConfigureApplications")
    can_configure_authentication_methods: Optional[StrictBool] = Field(default=None, alias="canConfigureAuthenticationMethods")
    can_configure_automation_actions: Optional[StrictBool] = Field(default=None, alias="canConfigureAutomationActions")
    can_configure_automation_policies: Optional[StrictBool] = Field(default=None, alias="canConfigureAutomationPolicies")
    can_configure_bizops: Optional[StrictBool] = Field(default=None, alias="canConfigureBizops")
    can_configure_custom_entities: Optional[StrictBool] = Field(default=None, alias="canConfigureCustomEntities")
    can_configure_database_management: Optional[StrictBool] = Field(default=None, alias="canConfigureDatabaseManagement")
    can_configure_eum_applications: Optional[StrictBool] = Field(default=None, alias="canConfigureEumApplications")
    can_configure_events_and_alerts: Optional[StrictBool] = Field(default=None, alias="canConfigureEventsAndAlerts")
    can_configure_global_alert_payload: Optional[StrictBool] = Field(default=None, alias="canConfigureGlobalAlertPayload")
    can_configure_global_application_smart_alerts: Optional[StrictBool] = Field(default=None, alias="canConfigureGlobalApplicationSmartAlerts")
    can_configure_global_infra_smart_alerts: Optional[StrictBool] = Field(default=None, alias="canConfigureGlobalInfraSmartAlerts")
    can_configure_global_log_smart_alerts: Optional[StrictBool] = Field(default=None, alias="canConfigureGlobalLogSmartAlerts")
    can_configure_global_synthetic_smart_alerts: Optional[StrictBool] = Field(default=None, alias="canConfigureGlobalSyntheticSmartAlerts")
    can_configure_integrations: Optional[StrictBool] = Field(default=None, alias="canConfigureIntegrations")
    can_configure_llm: Optional[StrictBool] = Field(default=None, alias="canConfigureLLM")
    can_configure_log_management: Optional[StrictBool] = Field(default=None, alias="canConfigureLogManagement")
    can_configure_log_retention_period: Optional[StrictBool] = Field(default=None, alias="canConfigureLogRetentionPeriod")
    can_configure_maintenance_windows: Optional[StrictBool] = Field(default=None, alias="canConfigureMaintenanceWindows")
    can_configure_mobile_app_monitoring: Optional[StrictBool] = Field(default=None, alias="canConfigureMobileAppMonitoring")
    can_configure_mobile_app_smart_alerts: Optional[StrictBool] = Field(default=None, alias="canConfigureMobileAppSmartAlerts")
    can_configure_personal_api_tokens: Optional[StrictBool] = Field(default=None, alias="canConfigurePersonalApiTokens")
    can_configure_releases: Optional[StrictBool] = Field(default=None, alias="canConfigureReleases")
    can_configure_service_level_correction_windows: Optional[StrictBool] = Field(default=None, alias="canConfigureServiceLevelCorrectionWindows")
    can_configure_service_level_smart_alerts: Optional[StrictBool] = Field(default=None, alias="canConfigureServiceLevelSmartAlerts")
    can_configure_service_levels: Optional[StrictBool] = Field(default=None, alias="canConfigureServiceLevels")
    can_configure_service_mapping: Optional[StrictBool] = Field(default=None, alias="canConfigureServiceMapping")
    can_configure_session_settings: Optional[StrictBool] = Field(default=None, alias="canConfigureSessionSettings")
    can_configure_subtraces: Optional[StrictBool] = Field(default=None, alias="canConfigureSubtraces")
    can_configure_synthetic_credentials: Optional[StrictBool] = Field(default=None, alias="canConfigureSyntheticCredentials")
    can_configure_synthetic_locations: Optional[StrictBool] = Field(default=None, alias="canConfigureSyntheticLocations")
    can_configure_synthetic_tests: Optional[StrictBool] = Field(default=None, alias="canConfigureSyntheticTests")
    can_configure_teams: Optional[StrictBool] = Field(default=None, alias="canConfigureTeams")
    can_configure_users: Optional[StrictBool] = Field(default=None, alias="canConfigureUsers")
    can_configure_website_conversions: Optional[StrictBool] = Field(default=None, alias="canConfigureWebsiteConversions")
    can_configure_website_smart_alerts: Optional[StrictBool] = Field(default=None, alias="canConfigureWebsiteSmartAlerts")
    can_create_heap_dump: Optional[StrictBool] = Field(default=None, alias="canCreateHeapDump")
    can_create_public_custom_dashboards: Optional[StrictBool] = Field(default=None, alias="canCreatePublicCustomDashboards")
    can_create_thread_dump: Optional[StrictBool] = Field(default=None, alias="canCreateThreadDump")
    can_delete_automation_action_history: Optional[StrictBool] = Field(default=None, alias="canDeleteAutomationActionHistory")
    can_delete_logs: Optional[StrictBool] = Field(default=None, alias="canDeleteLogs")
    can_edit_all_accessible_custom_dashboards: Optional[StrictBool] = Field(default=None, alias="canEditAllAccessibleCustomDashboards")
    can_install_new_agents: Optional[StrictBool] = Field(default=None, alias="canInstallNewAgents")
    can_invoke_alert_channel: Optional[StrictBool] = Field(default=None, alias="canInvokeAlertChannel")
    can_manually_close_issue: Optional[StrictBool] = Field(default=None, alias="canManuallyCloseIssue")
    can_run_automation_actions: Optional[StrictBool] = Field(default=None, alias="canRunAutomationActions")
    can_use_synthetic_credentials: Optional[StrictBool] = Field(default=None, alias="canUseSyntheticCredentials")
    can_view_account_and_billing_information: Optional[StrictBool] = Field(default=None, alias="canViewAccountAndBillingInformation")
    can_view_audit_log: Optional[StrictBool] = Field(default=None, alias="canViewAuditLog")
    can_view_biz_alerts: Optional[StrictBool] = Field(default=None, alias="canViewBizAlerts")
    can_view_business_activities: Optional[StrictBool] = Field(default=None, alias="canViewBusinessActivities")
    can_view_business_process_details: Optional[StrictBool] = Field(default=None, alias="canViewBusinessProcessDetails")
    can_view_business_processes: Optional[StrictBool] = Field(default=None, alias="canViewBusinessProcesses")
    can_view_log_volume: Optional[StrictBool] = Field(default=None, alias="canViewLogVolume")
    can_view_logs: Optional[StrictBool] = Field(default=None, alias="canViewLogs")
    can_view_synthetic_locations: Optional[StrictBool] = Field(default=None, alias="canViewSyntheticLocations")
    can_view_synthetic_test_results: Optional[StrictBool] = Field(default=None, alias="canViewSyntheticTestResults")
    can_view_synthetic_tests: Optional[StrictBool] = Field(default=None, alias="canViewSyntheticTests")
    can_view_trace_details: Optional[StrictBool] = Field(default=None, alias="canViewTraceDetails")
    created_by: Optional[StrictStr] = Field(default=None, alias="createdBy")
    created_on: Optional[StrictInt] = Field(default=None, alias="createdOn")
    expires_on: Optional[StrictInt] = Field(default=None, alias="expiresOn")
    id: Optional[StrictStr] = None
    internal_id: StrictStr = Field(alias="internalId")
    last_used_on: Optional[StrictInt] = Field(default=None, alias="lastUsedOn")
    limited_ai_gateway_scope: Optional[StrictBool] = Field(default=None, alias="limitedAiGatewayScope")
    limited_alert_channels_scope: Optional[StrictBool] = Field(default=None, alias="limitedAlertChannelsScope")
    limited_applications_scope: Optional[StrictBool] = Field(default=None, alias="limitedApplicationsScope")
    limited_automation_scope: Optional[StrictBool] = Field(default=None, alias="limitedAutomationScope")
    limited_biz_ops_scope: Optional[StrictBool] = Field(default=None, alias="limitedBizOpsScope")
    limited_gen_ai_scope: Optional[StrictBool] = Field(default=None, alias="limitedGenAIScope")
    limited_infrastructure_scope: Optional[StrictBool] = Field(default=None, alias="limitedInfrastructureScope")
    limited_kubernetes_scope: Optional[StrictBool] = Field(default=None, alias="limitedKubernetesScope")
    limited_linux_kvm_hypervisor_scope: Optional[StrictBool] = Field(default=None, alias="limitedLinuxKVMHypervisorScope")
    limited_logs_scope: Optional[StrictBool] = Field(default=None, alias="limitedLogsScope")
    limited_mobile_apps_scope: Optional[StrictBool] = Field(default=None, alias="limitedMobileAppsScope")
    limited_nutanix_scope: Optional[StrictBool] = Field(default=None, alias="limitedNutanixScope")
    limited_openstack_scope: Optional[StrictBool] = Field(default=None, alias="limitedOpenstackScope")
    limited_pcf_scope: Optional[StrictBool] = Field(default=None, alias="limitedPcfScope")
    limited_phmc_scope: Optional[StrictBool] = Field(default=None, alias="limitedPhmcScope")
    limited_pvc_scope: Optional[StrictBool] = Field(default=None, alias="limitedPvcScope")
    limited_sap_scope: Optional[StrictBool] = Field(default=None, alias="limitedSAPScope")
    limited_service_level_scope: Optional[StrictBool] = Field(default=None, alias="limitedServiceLevelScope")
    limited_synthetics_scope: Optional[StrictBool] = Field(default=None, alias="limitedSyntheticsScope")
    limited_vsphere_scope: Optional[StrictBool] = Field(default=None, alias="limitedVsphereScope")
    limited_websites_scope: Optional[StrictBool] = Field(default=None, alias="limitedWebsitesScope")
    limited_windows_hypervisor_scope: Optional[StrictBool] = Field(default=None, alias="limitedWindowsHypervisorScope")
    limited_xen_server_scope: Optional[StrictBool] = Field(default=None, alias="limitedXenServerScope")
    limited_zhmc_scope: Optional[StrictBool] = Field(default=None, alias="limitedZhmcScope")
    name: StrictStr
    __properties: ClassVar[List[str]] = ["accessGrantingToken", "canConfigureAgentRunMode", "canConfigureAgents", "canConfigureAiAgents", "canConfigureApdex", "canConfigureApiTokens", "canConfigureApplicationSmartAlerts", "canConfigureApplications", "canConfigureAuthenticationMethods", "canConfigureAutomationActions", "canConfigureAutomationPolicies", "canConfigureBizops", "canConfigureCustomEntities", "canConfigureDatabaseManagement", "canConfigureEumApplications", "canConfigureEventsAndAlerts", "canConfigureGlobalAlertPayload", "canConfigureGlobalApplicationSmartAlerts", "canConfigureGlobalInfraSmartAlerts", "canConfigureGlobalLogSmartAlerts", "canConfigureGlobalSyntheticSmartAlerts", "canConfigureIntegrations", "canConfigureLLM", "canConfigureLogManagement", "canConfigureLogRetentionPeriod", "canConfigureMaintenanceWindows", "canConfigureMobileAppMonitoring", "canConfigureMobileAppSmartAlerts", "canConfigurePersonalApiTokens", "canConfigureReleases", "canConfigureServiceLevelCorrectionWindows", "canConfigureServiceLevelSmartAlerts", "canConfigureServiceLevels", "canConfigureServiceMapping", "canConfigureSessionSettings", "canConfigureSubtraces", "canConfigureSyntheticCredentials", "canConfigureSyntheticLocations", "canConfigureSyntheticTests", "canConfigureTeams", "canConfigureUsers", "canConfigureWebsiteConversions", "canConfigureWebsiteSmartAlerts", "canCreateHeapDump", "canCreatePublicCustomDashboards", "canCreateThreadDump", "canDeleteAutomationActionHistory", "canDeleteLogs", "canEditAllAccessibleCustomDashboards", "canInstallNewAgents", "canInvokeAlertChannel", "canManuallyCloseIssue", "canRunAutomationActions", "canUseSyntheticCredentials", "canViewAccountAndBillingInformation", "canViewAuditLog", "canViewBizAlerts", "canViewBusinessActivities", "canViewBusinessProcessDetails", "canViewBusinessProcesses", "canViewLogVolume", "canViewLogs", "canViewSyntheticLocations", "canViewSyntheticTestResults", "canViewSyntheticTests", "canViewTraceDetails", "createdBy", "createdOn", "expiresOn", "id", "internalId", "lastUsedOn", "limitedAiGatewayScope", "limitedAlertChannelsScope", "limitedApplicationsScope", "limitedAutomationScope", "limitedBizOpsScope", "limitedGenAIScope", "limitedInfrastructureScope", "limitedKubernetesScope", "limitedLinuxKVMHypervisorScope", "limitedLogsScope", "limitedMobileAppsScope", "limitedNutanixScope", "limitedOpenstackScope", "limitedPcfScope", "limitedPhmcScope", "limitedPvcScope", "limitedSAPScope", "limitedServiceLevelScope", "limitedSyntheticsScope", "limitedVsphereScope", "limitedWebsitesScope", "limitedWindowsHypervisorScope", "limitedXenServerScope", "limitedZhmcScope", "name"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ApiToken from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ApiToken from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "accessGrantingToken": obj.get("accessGrantingToken"),
            "canConfigureAgentRunMode": obj.get("canConfigureAgentRunMode"),
            "canConfigureAgents": obj.get("canConfigureAgents"),
            "canConfigureAiAgents": obj.get("canConfigureAiAgents"),
            "canConfigureApdex": obj.get("canConfigureApdex"),
            "canConfigureApiTokens": obj.get("canConfigureApiTokens"),
            "canConfigureApplicationSmartAlerts": obj.get("canConfigureApplicationSmartAlerts"),
            "canConfigureApplications": obj.get("canConfigureApplications"),
            "canConfigureAuthenticationMethods": obj.get("canConfigureAuthenticationMethods"),
            "canConfigureAutomationActions": obj.get("canConfigureAutomationActions"),
            "canConfigureAutomationPolicies": obj.get("canConfigureAutomationPolicies"),
            "canConfigureBizops": obj.get("canConfigureBizops"),
            "canConfigureCustomEntities": obj.get("canConfigureCustomEntities"),
            "canConfigureDatabaseManagement": obj.get("canConfigureDatabaseManagement"),
            "canConfigureEumApplications": obj.get("canConfigureEumApplications"),
            "canConfigureEventsAndAlerts": obj.get("canConfigureEventsAndAlerts"),
            "canConfigureGlobalAlertPayload": obj.get("canConfigureGlobalAlertPayload"),
            "canConfigureGlobalApplicationSmartAlerts": obj.get("canConfigureGlobalApplicationSmartAlerts"),
            "canConfigureGlobalInfraSmartAlerts": obj.get("canConfigureGlobalInfraSmartAlerts"),
            "canConfigureGlobalLogSmartAlerts": obj.get("canConfigureGlobalLogSmartAlerts"),
            "canConfigureGlobalSyntheticSmartAlerts": obj.get("canConfigureGlobalSyntheticSmartAlerts"),
            "canConfigureIntegrations": obj.get("canConfigureIntegrations"),
            "canConfigureLLM": obj.get("canConfigureLLM"),
            "canConfigureLogManagement": obj.get("canConfigureLogManagement"),
            "canConfigureLogRetentionPeriod": obj.get("canConfigureLogRetentionPeriod"),
            "canConfigureMaintenanceWindows": obj.get("canConfigureMaintenanceWindows"),
            "canConfigureMobileAppMonitoring": obj.get("canConfigureMobileAppMonitoring"),
            "canConfigureMobileAppSmartAlerts": obj.get("canConfigureMobileAppSmartAlerts"),
            "canConfigurePersonalApiTokens": obj.get("canConfigurePersonalApiTokens"),
            "canConfigureReleases": obj.get("canConfigureReleases"),
            "canConfigureServiceLevelCorrectionWindows": obj.get("canConfigureServiceLevelCorrectionWindows"),
            "canConfigureServiceLevelSmartAlerts": obj.get("canConfigureServiceLevelSmartAlerts"),
            "canConfigureServiceLevels": obj.get("canConfigureServiceLevels"),
            "canConfigureServiceMapping": obj.get("canConfigureServiceMapping"),
            "canConfigureSessionSettings": obj.get("canConfigureSessionSettings"),
            "canConfigureSubtraces": obj.get("canConfigureSubtraces"),
            "canConfigureSyntheticCredentials": obj.get("canConfigureSyntheticCredentials"),
            "canConfigureSyntheticLocations": obj.get("canConfigureSyntheticLocations"),
            "canConfigureSyntheticTests": obj.get("canConfigureSyntheticTests"),
            "canConfigureTeams": obj.get("canConfigureTeams"),
            "canConfigureUsers": obj.get("canConfigureUsers"),
            "canConfigureWebsiteConversions": obj.get("canConfigureWebsiteConversions"),
            "canConfigureWebsiteSmartAlerts": obj.get("canConfigureWebsiteSmartAlerts"),
            "canCreateHeapDump": obj.get("canCreateHeapDump"),
            "canCreatePublicCustomDashboards": obj.get("canCreatePublicCustomDashboards"),
            "canCreateThreadDump": obj.get("canCreateThreadDump"),
            "canDeleteAutomationActionHistory": obj.get("canDeleteAutomationActionHistory"),
            "canDeleteLogs": obj.get("canDeleteLogs"),
            "canEditAllAccessibleCustomDashboards": obj.get("canEditAllAccessibleCustomDashboards"),
            "canInstallNewAgents": obj.get("canInstallNewAgents"),
            "canInvokeAlertChannel": obj.get("canInvokeAlertChannel"),
            "canManuallyCloseIssue": obj.get("canManuallyCloseIssue"),
            "canRunAutomationActions": obj.get("canRunAutomationActions"),
            "canUseSyntheticCredentials": obj.get("canUseSyntheticCredentials"),
            "canViewAccountAndBillingInformation": obj.get("canViewAccountAndBillingInformation"),
            "canViewAuditLog": obj.get("canViewAuditLog"),
            "canViewBizAlerts": obj.get("canViewBizAlerts"),
            "canViewBusinessActivities": obj.get("canViewBusinessActivities"),
            "canViewBusinessProcessDetails": obj.get("canViewBusinessProcessDetails"),
            "canViewBusinessProcesses": obj.get("canViewBusinessProcesses"),
            "canViewLogVolume": obj.get("canViewLogVolume"),
            "canViewLogs": obj.get("canViewLogs"),
            "canViewSyntheticLocations": obj.get("canViewSyntheticLocations"),
            "canViewSyntheticTestResults": obj.get("canViewSyntheticTestResults"),
            "canViewSyntheticTests": obj.get("canViewSyntheticTests"),
            "canViewTraceDetails": obj.get("canViewTraceDetails"),
            "createdBy": obj.get("createdBy"),
            "createdOn": obj.get("createdOn"),
            "expiresOn": obj.get("expiresOn"),
            "id": obj.get("id"),
            "internalId": obj.get("internalId"),
            "lastUsedOn": obj.get("lastUsedOn"),
            "limitedAiGatewayScope": obj.get("limitedAiGatewayScope"),
            "limitedAlertChannelsScope": obj.get("limitedAlertChannelsScope"),
            "limitedApplicationsScope": obj.get("limitedApplicationsScope"),
            "limitedAutomationScope": obj.get("limitedAutomationScope"),
            "limitedBizOpsScope": obj.get("limitedBizOpsScope"),
            "limitedGenAIScope": obj.get("limitedGenAIScope"),
            "limitedInfrastructureScope": obj.get("limitedInfrastructureScope"),
            "limitedKubernetesScope": obj.get("limitedKubernetesScope"),
            "limitedLinuxKVMHypervisorScope": obj.get("limitedLinuxKVMHypervisorScope"),
            "limitedLogsScope": obj.get("limitedLogsScope"),
            "limitedMobileAppsScope": obj.get("limitedMobileAppsScope"),
            "limitedNutanixScope": obj.get("limitedNutanixScope"),
            "limitedOpenstackScope": obj.get("limitedOpenstackScope"),
            "limitedPcfScope": obj.get("limitedPcfScope"),
            "limitedPhmcScope": obj.get("limitedPhmcScope"),
            "limitedPvcScope": obj.get("limitedPvcScope"),
            "limitedSAPScope": obj.get("limitedSAPScope"),
            "limitedServiceLevelScope": obj.get("limitedServiceLevelScope"),
            "limitedSyntheticsScope": obj.get("limitedSyntheticsScope"),
            "limitedVsphereScope": obj.get("limitedVsphereScope"),
            "limitedWebsitesScope": obj.get("limitedWebsitesScope"),
            "limitedWindowsHypervisorScope": obj.get("limitedWindowsHypervisorScope"),
            "limitedXenServerScope": obj.get("limitedXenServerScope"),
            "limitedZhmcScope": obj.get("limitedZhmcScope"),
            "name": obj.get("name")
        })
        return _obj


